%%%Additional Information GUI
function varargout = AddInfo(varargin)
% ADDINFO M-file for AddInfo.fig
%      ADDINFO, by itself, creates a new ADDINFO or raises the existing
%      singleton*.
%
%      H = ADDINFO returns the handle to a new ADDINFO or the handle to
%      the existing singleton*.
%
%      ADDINFO('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in ADDINFO.M with the given input arguments.
%
%      ADDINFO('Property','Value',...) creates a new ADDINFO or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before AddInfo_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to AddInfo_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help AddInfo

% Last Modified by GUIDE v2.5 26-May-2011 11:06:01

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @AddInfo_OpeningFcn, ...
                   'gui_OutputFcn',  @AddInfo_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before AddInfo is made visible.
function AddInfo_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to AddInfo (see VARARGIN)

% Choose default command line output for AddInfo
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes AddInfo wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = AddInfo_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function axes1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to axes1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
imshow('AdditionalInfo.jpg')
axis image
% Hint: place code in OpeningFcn to populate axes1


% --- Executes on button press in GTPolyphen2.
function GTPolyphen2_Callback(hObject, eventdata, handles)
% hObject    handle to GTPolyphen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://genetics.bwh.harvard.edu/pph2/ -browser


% --- Executes on button press in GTConSurf.
function GTConSurf_Callback(hObject, eventdata, handles)
% hObject    handle to GTConSurf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://consurf.tau.ac.il/index_nucleotides.php -browser


% --- Executes on button press in GTTMpred.
function GTTMpred_Callback(hObject, eventdata, handles)
% hObject    handle to GTTMpred (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://www.ch.embnet.org/software/TMPRED_form.html -browser


% --- Executes on button press in GTOmim.
function GTOmim_Callback(hObject, eventdata, handles)
% hObject    handle to GTOmim (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://www.ncbi.nlm.nih.gov/omim/ -browser


% --- Executes on button press in GTUCSC.
function GTUCSC_Callback(hObject, eventdata, handles)
% hObject    handle to GTUCSC (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://genome.cse.ucsc.edu -browser
